Press n or j to go to the next uncovered block, b, p or k for the previous block.
| 1 2 3 4 5 6 7 | import { CheckboxProps as MuiCheckboxProps } from "@mui/material";
export interface CheckboxProps extends MuiCheckboxProps {
size?: "small" | "medium";
error?: boolean;
}
|